pub struct DMSCTrafficRoute {
pub name: String,
pub source_service: String,
pub destination_service: String,
pub match_criteria: DMSCMatchCriteria,
pub route_action: DMSCRouteAction,
pub retry_policy: Option<DMSCRetryPolicy>,
pub timeout: Option<Duration>,
pub fault_injection: Option<DMSCFaultInjection>,
}Fields
name: Stringsource_service: Stringdestination_service: Stringmatch_criteria: DMSCMatchCriteriaroute_action: DMSCRouteActionretry_policy: Option<DMSCRetryPolicy>timeout: Option<Duration>fault_injection: Option<DMSCFaultInjection>Trait Implementations
Sourceimpl Clone for DMSCTrafficRoute
impl Clone for DMSCTrafficRoute
Sourcefn clone(&self) -> DMSCTrafficRoute
fn clone(&self) -> DMSCTrafficRoute
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DMSCTrafficRoute
impl Debug for DMSCTrafficRoute
Sourceimpl<'de> Deserialize<'de> for DMSCTrafficRoute
impl<'de> Deserialize<'de> for DMSCTrafficRoute
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<'py> IntoPyObject<'py> for DMSCTrafficRoute
impl<'py> IntoPyObject<'py> for DMSCTrafficRoute
Sourcetype Target = DMSCTrafficRoute
type Target = DMSCTrafficRoute
The Python output type
Sourcetype Output = Bound<'py, <DMSCTrafficRoute as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DMSCTrafficRoute as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DMSCTrafficRoute
impl PyClass for DMSCTrafficRoute
Sourceimpl PyClassImpl for DMSCTrafficRoute
impl PyClassImpl for DMSCTrafficRoute
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DMSCTrafficRoute>
type ThreadChecker = SendablePyClass<DMSCTrafficRoute>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DMSCTrafficRoute
impl PyClassNewTextSignature for DMSCTrafficRoute
const TEXT_SIGNATURE: &'static str = "(name, source_service, destination_service)"
Sourceimpl PyMethods<DMSCTrafficRoute> for PyClassImplCollector<DMSCTrafficRoute>
impl PyMethods<DMSCTrafficRoute> for PyClassImplCollector<DMSCTrafficRoute>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DMSCTrafficRoute
impl PyTypeInfo for DMSCTrafficRoute
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.Sourceimpl Serialize for DMSCTrafficRoute
impl Serialize for DMSCTrafficRoute
impl DerefToPyAny for DMSCTrafficRoute
impl ExtractPyClassWithClone for DMSCTrafficRoute